indexing

	description: "TCP/SOCK_STREAM sockets."

	author: "Berend de Boer"
	date: "$Date: 2003/01/09 $"
	revision: "$Revision: #3 $"


class

	SUS_TCP_SOCKET


inherit

	SUS_SOCKET


creation

	listen_by_address,
	open_by_address


feature {NONE} -- Socket specific open functions

	listen_by_address (sa: SUS_SOCKET_ADDRESS) is
			-- Listen on socket for address specified in `sa'.
		require
			sa_not_void: sa /= Void
			closed: not is_open
		local
			r: INTEGER
			a_fd: INTEGER
		do
			a_fd := new_socket (sa)
			if a_fd /= -1 then
				r := posix_bind (a_fd, sa.ptr, sa.length)
				if r = -1 then
					raise_posix_error
				else
					r := posix_listen (a_fd, backlog_default)
					if r = -1 then
						raise_posix_error
					else
						is_open := True
						-- Optimize for streaming reads.
						set_streaming (True)
					end
				end
			end
			set_fd (a_fd, True)
		ensure
			is_opened: security.error_handling.exceptions_enabled implies is_open
			open_files_increased_by_one:
				is_owner implies
					security.files.open_files = old security.files.open_files + 1
		end

	open_by_address (sa: SUS_SOCKET_ADDRESS) is
			-- Open socket to server specified in `sa'.
		require
			sa_not_void: sa /= Void
			closed: not is_open
		local
			r: INTEGER
			a_fd: INTEGER
		do
			a_fd := new_socket (sa)
			if a_fd /= -1 then
				r := posix_connect (a_fd, sa.ptr, sa.length)
				if r = -1 then
					raise_posix_error
				else
					is_open := True
					-- Optimize for streaming reads.
					set_streaming (True)
				end
			end
			set_fd (a_fd, True)
		ensure
			is_opened: security.error_handling.exceptions_enabled implies is_open
			open_files_increased_by_one:
				is_owner implies
					security.files.open_files = old security.files.open_files + 1
		end


feature {NONE} -- Implementation

	backlog_default: INTEGER is 1024

	new_socket (sa: SUS_SOCKET_ADDRESS): INTEGER is
			-- Return file descriptor for new socket. Raises error when
			-- exceptions are enabled, else -1.
		do
			Result := posix_socket (
				sa.host.address_type,
				sa.service.protocol_type,
				0)
			if Result = -1 then
				raise_posix_error
			end
		ensure
			valid_socket_or_error: Result >= -1
		end

end
