indexing

	description: "getest based test for EPX_MIME classes."

	author: "Berend de Boer"
	date: "$Date: 2003/01/09 $"
	revision: "$Revision: #1 $"


deferred class

	TEST_MIME_PARSER

inherit

	TS_TEST_CASE

feature -- Tests

	test_mail1 is
		local
			file: STDC_TEXT_FILE
			parser: EPX_MIME_PARSER
		do
			create file.open_read ("test1.msg")
			create parser.make_from_file (file)
			parser.parse
			assert ("test1.msg parsed ok", not parser.syntax_error)
			parser.part.fields.search ("X-Sieve")
			assert ("Message has field X-Sieve", parser.part.fields.found)
			debug
				print ("length sieve: ")
				print (parser.part.fields.found_item.value.count)
				print ("%N")
			end
			assert_equal ("Content of field X-Sieve", "cmu-sieve 2.0", parser.part.fields.found_item.value)
			parser.part.fields.search ("MIME-Version")
			assert ("Field has no MIME-Version", not parser.part.fields.found)
			print_body (parser.part.body)

			-- test if we can invoke the parser twice
			file.close
			file.open_read ("test1.msg")
			parser.make_from_file (file)
			parser.parse
			assert ("test1.msg parsed ok", not parser.syntax_error)
		end

	test_mail2 is
		local
			file: STDC_TEXT_FILE
			parser: EPX_MIME_PARSER
		do
			create file.open_read ("test2.msg")
			create parser.make_from_file (file)
			parser.parse
			assert ("test2.msg parsed ok", not parser.syntax_error)
			parser.part.fields.search ("MIME-Version")
			assert ("Field has MIME-Version", parser.part.fields.found)
			assert_equal ("Content of field MIME-Version", "1.0", parser.part.fields.found_item.value)
			print_body (parser.part.body)
		end

	test_mail3 is
		local
			file: STDC_TEXT_FILE
			parser: EPX_MIME_PARSER
		do
			create file.open_read ("test3.msg")
			create parser.make_from_file (file)
			parser.parse
			assert ("test3.msg parsed ok", not parser.syntax_error)
			print_body (parser.part.body)
		end

	test_mail4 is
		local
			file: STDC_TEXT_FILE
			parser: EPX_MIME_PARSER
			multipart_body: EPX_MIME_BODY_MULTIPART
		do
			create file.open_read ("test4.msg")
			create parser.make_from_file (file)
			parser.parse
			assert ("test4.msg parsed ok", not parser.syntax_error)
			parser.part.fields.search ("MIME-Version")
			assert ("Field has MIME-Version", parser.part.fields.found)
			assert_equal ("Content of field MIME-Version", "1.0", parser.part.fields.found_item.value)
			parser.part.fields.search ("Content-Type")
			assert ("Have field Content-Type", parser.part.fields.found)
			assert ("Feature content_type not void", parser.part.content_type /= Void)
			assert_equal ("Have two parameters", 2, parser.part.content_type.parameters.count)
			assert ("Have parameter report-type", parser.part.content_type.parameters.has ("report-type"))
			assert ("Have parameter boundary", parser.part.content_type.parameters.has ("boundary"))
			assert ("Body is multi-part", parser.part.body.is_multipart)
			multipart_body ?= parser.part.body
			assert ("Multipart body not void.", multipart_body /= Void)
			assert_equal ("Number of parts", 3, multipart_body.parts.count)
			print_body (multipart_body.parts.first.body)
			assert_equal ("First part has one field.", 1, parser.part.body.part (1).fields.count)
		end

	test_parsing_cgi_input is
		local
			file: STDC_TEXT_FILE
			parser: EPX_MIME_PARSER
			string_body: EPX_MIME_BODY_STRING
			file_body: EPX_MIME_BODY_FILE
		do
			create file.open_read ("cgi_input1.txt")
			create parser.make_from_file (file)
			parser.parse
			assert_equal ("Two fields", 2, parser.part.fields.count)
			assert ("Body is multi-part", parser.part.body.is_multipart)
			assert_equal ("Number of parts", 3, parser.part.body.parts_count)
			debug ("mime")
				print_body (parser.part.body.part (1).body)
			end
			file_body ?= parser.part.body.part (1).body
			assert ("1st part is a file body", file_body /= Void)
			string_body ?= parser.part.body.part (2).body
			assert ("2nd part is string body", string_body /= Void)
			assert_equal ("Contents of button", "Upload file(s)", string_body.as_string)
			string_body ?= parser.part.body.part (3).body
			assert ("3rd part is string_body", string_body /= Void)
			assert_equal ("Contents of uid", "1804289383", string_body.as_string)
		end

feature {NONE} -- Helpers

	print_body (body: EPX_MIME_BODY) is
		local
			text_body: EPX_MIME_BODY_TEXT
			s: STRING
		do
			text_body ?= body
			s := text_body.as_string
			print ("====%N")
			print (s)
			print ("====%N")
		end

end
