indexing

	description: "Test SUS tcp sockets by connecting to an HTTP server."

	author: "Berend de Boer"
	date: "$Date: 2003/01/09 $"
	revision: "$Revision: #1 $"

	notes: "Need VE 4.0 with patched STRING, or a higher version."


deferred class

	TEST_HTTP

inherit

	TS_TEST_CASE

	EPX_MIME_FIELD_NAMES

feature

	test_get is
		local
			client: EPX_HTTP_10_CLIENT
			content_length: EPX_MIME_FIELD_CONTENT_LENGTH
		do
			--create client.make ("localhost")
			create client.make ("www.freebsd.org")
			--create client.make_from_port ("swiki.gsug.org", 8080)
			client.get ("/index.html")
			client.read_response
			--print_response (client)
			assert_equal ("Version version", "HTTP/1.0", client.server_version)
			assert_equal ("Response code", 200, client.response_code)
			assert_equal ("Response phrase", "OK", client.response_phrase)
			client.fields.search (field_name_content_length)
			assert ("Has Content-Length", client.fields.found)
			content_length ?= client.fields.found_item
			assert ("Content-Length positive", content_length.length > 0)
			debug ("http")
				print (client.body.as_string)
			end

			-- a second time
			client.get ("/gifs/freebsd_1.gif")
			client.read_response
		end

	test_non_existing is
		local
			client: EPX_HTTP_10_CLIENT
		do
			create client.make ("www.freebsd.org")
			client.get ("/nonexisting.html")
			--print_response (client)
			client.read_response
			assert_equal ("Version version", "HTTP/1.0", client.server_version)
			assert_equal ("Response code", 404, client.response_code)
			assert_equal ("Response phrase", "Not Found", client.response_phrase)
		end

	test_head is
		local
			client: EPX_HTTP_10_CLIENT
			content_length: EPX_MIME_FIELD_CONTENT_LENGTH
		do
			create client.make ("www.freebsd.org")
			client.head ("/index.html")
			--print_response (client)
			client.read_response
			assert_equal ("Version version", "HTTP/1.0", client.server_version)
			assert_equal ("Response code", 200, client.response_code)
			assert_equal ("Response phrase", "OK", client.response_phrase)
			assert ("Has Last-Modified", client.fields.has (field_name_last_modified))
			client.fields.search (field_name_content_length)
			assert ("Has Content-Length", client.fields.found)
			content_length ?= client.fields.found_item
			assert ("Content-Length positive", content_length.length > 0)
		end

	test_options is
		local
			client: EPX_HTTP_11_CLIENT
		do
			create client.make ("www.apache.org")
			client.options ("/index.html")
			--print_response (client)
			client.read_response
			--assert_equal ("Version version", "HTTP/1.1", client.server_version)
			assert_equal ("Version version", "HTTP/1.0", client.server_version)
			assert_equal ("Response code", 200, client.response_code)
			assert_equal ("Response phrase", "OK", client.response_phrase)
			assert ("Has Allow", client.fields.has (field_name_allow))
		end


feature {NONE} -- Implementation

	print_response (client: EPX_HTTP_CLIENT) is
		do
			from
				client.http.read_string (512)
			until
				client.http.eof
			loop
				print (client.http.last_string)
				client.http.read_string (512)
			end
			print ("%N")
		end

end
